var indexSectionsWithContent =
{
  0: "abcdefhiklmnopqrstuvw",
  1: "l",
  2: "l",
  3: "l",
  4: "l",
  5: "l",
  6: "l",
  7: "acdefhilmoqrstu",
  8: "abcdehiklstv"
};

var indexSectionNames =
{
  0: "all",
  1: "files",
  2: "functions",
  3: "typedefs",
  4: "enums",
  5: "enumvalues",
  6: "defines",
  7: "groups",
  8: "pages"
};

var indexSectionLabels =
{
  0: "All",
  1: "Files",
  2: "Functions",
  3: "Typedefs",
  4: "Enumerations",
  5: "Enumerator",
  6: "Macros",
  7: "Modules",
  8: "Pages"
};

